#
# PySNMP MIB module RFC1381-MIB (http://pysnmp.sf.net)
# ASN.1 source http://mibs.snmplabs.com:80/asn1/RFC1381-MIB
# Produced by pysmi-0.0.7 at Sun Feb 14 00:26:21 2016
# On host bldfarm platform Linux version 4.1.13-100.fc21.x86_64 by user goose
# Using Python version 3.5.0 (default, Jan  5 2016, 17:11:52) 
#
( ObjectIdentifier, Integer, OctetString, ) = mibBuilder.importSymbols("ASN1", "ObjectIdentifier", "Integer", "OctetString")
( NamedValues, ) = mibBuilder.importSymbols("ASN1-ENUMERATION", "NamedValues")
( ValueSizeConstraint, SingleValueConstraint, ConstraintsIntersection, ValueRangeConstraint, ConstraintsUnion, ) = mibBuilder.importSymbols("ASN1-REFINEMENT", "ValueSizeConstraint", "SingleValueConstraint", "ConstraintsIntersection", "ValueRangeConstraint", "ConstraintsUnion")
( PositiveInteger, ) = mibBuilder.importSymbols("RFC1253-MIB", "PositiveInteger")
( NotificationGroup, ModuleCompliance, ) = mibBuilder.importSymbols("SNMPv2-CONF", "NotificationGroup", "ModuleCompliance")
( Integer32, TimeTicks, MibIdentifier, transmission, Counter64, IpAddress, Counter32, Bits, NotificationType, MibScalar, MibTable, MibTableRow, MibTableColumn, iso, Unsigned32, ObjectIdentity, ModuleIdentity, Gauge32, ) = mibBuilder.importSymbols("SNMPv2-SMI", "Integer32", "TimeTicks", "MibIdentifier", "transmission", "Counter64", "IpAddress", "Counter32", "Bits", "NotificationType", "MibScalar", "MibTable", "MibTableRow", "MibTableColumn", "iso", "Unsigned32", "ObjectIdentity", "ModuleIdentity", "Gauge32")
( DisplayString, TextualConvention, ) = mibBuilder.importSymbols("SNMPv2-TC", "DisplayString", "TextualConvention")
lapb = MibIdentifier((1, 3, 6, 1, 2, 1, 10, 16))
class IfIndexType(Integer32):
    subtypeSpec = Integer32.subtypeSpec+ValueRangeConstraint(1,2147483647)

lapbAdmnTable = MibTable((1, 3, 6, 1, 2, 1, 10, 16, 1), )
if mibBuilder.loadTexts: lapbAdmnTable.setDescription('This table contains objects that can be\n                          changed to manage a LAPB interface.\n                          Changing one of these parameters may take\n                          effect in the operating LAPB immediately or\n                          may wait until the interface is restarted\n                          depending on the details of the\n                          implementation.\n\n                          Most of the objects in this read-write table\n                          have corresponding read-only objects in the\n                          lapbOperTable that return the current\n                          operating value.\n\n                          The operating values may be different from\n                          these configured values if changed by XID\n                          negotiation or if a configured parameter was\n                          changed after the interface was started.')
lapbAdmnEntry = MibTableRow((1, 3, 6, 1, 2, 1, 10, 16, 1, 1), ).setIndexNames((0, "RFC1381-MIB", "lapbAdmnIndex"))
if mibBuilder.loadTexts: lapbAdmnEntry.setDescription('Configured parameter values for a specific\n                          LAPB.')
lapbAdmnIndex = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 16, 1, 1, 1), IfIndexType()).setMaxAccess("readonly")
if mibBuilder.loadTexts: lapbAdmnIndex.setDescription('The ifIndex value for the LAPB interface.')
lapbAdmnStationType = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 16, 1, 1, 2), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2, 3,))).clone(namedValues=NamedValues(("dte", 1), ("dce", 2), ("dxe", 3),)).clone('dte')).setMaxAccess("readwrite")
if mibBuilder.loadTexts: lapbAdmnStationType.setDescription('Identifies the desired station type of this\n                          interface.')
lapbAdmnControlField = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 16, 1, 1, 3), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2,))).clone(namedValues=NamedValues(("modulo8", 1), ("modulo128", 2),)).clone('modulo8')).setMaxAccess("readwrite")
if mibBuilder.loadTexts: lapbAdmnControlField.setDescription('The desired size of the sequence numbers\n                          used to number frames.')
lapbAdmnTransmitN1FrameSize = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 16, 1, 1, 4), PositiveInteger().clone(36000)).setMaxAccess("readwrite")
if mibBuilder.loadTexts: lapbAdmnTransmitN1FrameSize.setDescription('The default maximum N1 frame size desired\n                          in number of bits for a frame transmitted by\n                          this DTE.  This excludes flags and 0 bits\n                          inserted for transparency.')
lapbAdmnReceiveN1FrameSize = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 16, 1, 1, 5), PositiveInteger().clone(36000)).setMaxAccess("readwrite")
if mibBuilder.loadTexts: lapbAdmnReceiveN1FrameSize.setDescription('The default maximum N1 frame size desired\n                          in number of bits for a frame the DCE/remote\n                          DTE transmits to this DTE.  This excludes\n                          flags and 0 bits inserted for transparency.')
lapbAdmnTransmitKWindowSize = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 16, 1, 1, 6), Integer32().subtype(subtypeSpec=ValueRangeConstraint(1,127)).clone(7)).setMaxAccess("readwrite")
if mibBuilder.loadTexts: lapbAdmnTransmitKWindowSize.setDescription('The default transmit window size for this\n                          Interface.  This is the maximum number of\n                          unacknowledged sequenced PDUs that may be\n                          outstanding from this DTE at any one time.')
lapbAdmnReceiveKWindowSize = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 16, 1, 1, 7), Integer32().subtype(subtypeSpec=ValueRangeConstraint(1,127)).clone(7)).setMaxAccess("readwrite")
if mibBuilder.loadTexts: lapbAdmnReceiveKWindowSize.setDescription('The default receive window size for this\n                          Interface.  This is the maximum number of\n\n\n                          unacknowledged sequenced PDUs that may be\n                          outstanding from the DCE/remote DTE at any\n                          one time.')
lapbAdmnN2RxmitCount = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 16, 1, 1, 8), Integer32().subtype(subtypeSpec=ValueRangeConstraint(0,65535)).clone(20)).setMaxAccess("readwrite")
if mibBuilder.loadTexts: lapbAdmnN2RxmitCount.setDescription('The default N2 retry counter for this\n                          interface.  This specifies the number of\n                          times a PDU will be resent after the T1\n                          timer expires without an acknowledgement for\n                          the PDU.')
lapbAdmnT1AckTimer = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 16, 1, 1, 9), PositiveInteger().clone(3000)).setMaxAccess("readwrite")
if mibBuilder.loadTexts: lapbAdmnT1AckTimer.setDescription('The default T1 timer for this interface.\n                          This specifies the maximum time in\n                          Milliseconds to wait for acknowledgment of a\n                          PDU.')
lapbAdmnT2AckDelayTimer = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 16, 1, 1, 10), PositiveInteger()).setMaxAccess("readwrite")
if mibBuilder.loadTexts: lapbAdmnT2AckDelayTimer.setDescription('The default T2 timer for this interface.\n                          This specifies the maximum time in\n                          Milliseconds to wait before sending an\n                          acknowledgment for a sequenced PDU.  A value\n                          of zero means there will be no delay in\n                          acknowledgement generation.')
lapbAdmnT3DisconnectTimer = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 16, 1, 1, 11), PositiveInteger().clone(60000)).setMaxAccess("readwrite")
if mibBuilder.loadTexts: lapbAdmnT3DisconnectTimer.setDescription('The T3 timer for this interface.  This\n                          specifies the time in Milliseconds to wait\n                          before considering the link disconnected.  A\n                          value of zero indicates the link will be\n                          considered disconnected upon completion of\n                          the frame exchange to disconnect the link.')
lapbAdmnT4IdleTimer = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 16, 1, 1, 12), PositiveInteger().clone(2147483647)).setMaxAccess("readwrite")
if mibBuilder.loadTexts: lapbAdmnT4IdleTimer.setDescription('The T4 timer for this interface.  This\n                          specifies the maximum time in Milliseconds\n                          to allow without frames being exchanged on\n                          the data link.  A value of 2147483647\n                          indicates no idle timer is being kept.')
lapbAdmnActionInitiate = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 16, 1, 1, 13), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2, 3, 4, 5,))).clone(namedValues=NamedValues(("sendSABM", 1), ("sendDISC", 2), ("sendDM", 3), ("none", 4), ("other", 5),)).clone('sendSABM')).setMaxAccess("readwrite")
if mibBuilder.loadTexts: lapbAdmnActionInitiate.setDescription('This identifies the action LAPB will take\n                          to initiate link set-up.')
lapbAdmnActionRecvDM = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 16, 1, 1, 14), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2, 3,))).clone(namedValues=NamedValues(("sendSABM", 1), ("sendDISC", 2), ("other", 3),)).clone('sendSABM')).setMaxAccess("readwrite")
if mibBuilder.loadTexts: lapbAdmnActionRecvDM.setDescription('This identifies the action LAPB will take\n                          when it receives a DM response.')
lapbOperTable = MibTable((1, 3, 6, 1, 2, 1, 10, 16, 2), )
if mibBuilder.loadTexts: lapbOperTable.setDescription('This table contains configuration\n                          information about interface parameters\n                          currently set in the interface.  Many of\n                          these objects have corresponding objects in\n                  the lapbAdmnTable.')
lapbOperEntry = MibTableRow((1, 3, 6, 1, 2, 1, 10, 16, 2, 1), ).setIndexNames((0, "RFC1381-MIB", "lapbOperIndex"))
if mibBuilder.loadTexts: lapbOperEntry.setDescription('Currently set parameter values for a\n                          specific LAPB.')
lapbOperIndex = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 16, 2, 1, 1), IfIndexType()).setMaxAccess("readonly")
if mibBuilder.loadTexts: lapbOperIndex.setDescription('The ifIndex value for the LAPB interface.')
lapbOperStationType = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 16, 2, 1, 2), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2, 3,))).clone(namedValues=NamedValues(("dte", 1), ("dce", 2), ("dxe", 3),))).setMaxAccess("readonly")
if mibBuilder.loadTexts: lapbOperStationType.setDescription('Identifies the current operating station\n                          type of this interface.  A value of dxe (3)\n                          indicates XID negotiation has not yet taken\n                          place.')
lapbOperControlField = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 16, 2, 1, 3), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2,))).clone(namedValues=NamedValues(("modulo8", 1), ("modulo128", 2),))).setMaxAccess("readonly")
if mibBuilder.loadTexts: lapbOperControlField.setDescription('The current operating size of the sequence\n                          numbers used to number frames.')
lapbOperTransmitN1FrameSize = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 16, 2, 1, 4), PositiveInteger()).setMaxAccess("readonly")
if mibBuilder.loadTexts: lapbOperTransmitN1FrameSize.setDescription('The current operating N1 frame size used\n                          for the maximum number of bits in a frame\n                          this DTE can transmit.  This excludes flags\n                          and 0 bits inserted for transparency.')
lapbOperReceiveN1FrameSize = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 16, 2, 1, 5), PositiveInteger()).setMaxAccess("readonly")
if mibBuilder.loadTexts: lapbOperReceiveN1FrameSize.setDescription('The current operating N1 frame size used\n                          for the maximum number of bits in a frame\n                          the DCE/remote DTE can transmit.  This\n                          excludes flags and 0 bits inserted for\n                          transparency.')
lapbOperTransmitKWindowSize = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 16, 2, 1, 6), Integer32().subtype(subtypeSpec=ValueRangeConstraint(1,127))).setMaxAccess("readonly")
if mibBuilder.loadTexts: lapbOperTransmitKWindowSize.setDescription('The current PDU window size this Interface\n                          uses to transmit.  This is the maximum\n\n\n                          number of unacknowledged sequenced PDUs that\n                          may be outstanding from this DTE at any one\n                          time.')
lapbOperReceiveKWindowSize = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 16, 2, 1, 7), Integer32().subtype(subtypeSpec=ValueRangeConstraint(1,127))).setMaxAccess("readonly")
if mibBuilder.loadTexts: lapbOperReceiveKWindowSize.setDescription('The current receive PDU window size for\n                          this Interface.  This is the maximum number\n                          of unacknowledged sequenced PDUs that may be\n                          outstanding from the DCE/remote DTE at any\n                          one time.')
lapbOperN2RxmitCount = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 16, 2, 1, 8), Integer32().subtype(subtypeSpec=ValueRangeConstraint(0,65535))).setMaxAccess("readonly")
if mibBuilder.loadTexts: lapbOperN2RxmitCount.setDescription('The current N2 retry counter used for this\n                          interface.  This specifies the number of\n                          times a PDU will be resent after the T1\n                          timer expires without an acknowledgement for\n                          the PDU.')
lapbOperT1AckTimer = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 16, 2, 1, 9), PositiveInteger()).setMaxAccess("readonly")
if mibBuilder.loadTexts: lapbOperT1AckTimer.setDescription('The current T1 timer for this interface.\n                          This specifies the maximum time in\n                          Milliseconds to wait for acknowledgment of a\n                          PDU.')
lapbOperT2AckDelayTimer = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 16, 2, 1, 10), PositiveInteger()).setMaxAccess("readonly")
if mibBuilder.loadTexts: lapbOperT2AckDelayTimer.setDescription('The current T2 timer for this interface.\n                          This specifies the maximum time in\n                          Milliseconds to wait before sending an\n                          acknowledgment for a sequenced PDU.  A value\n                          of zero means there will be no delay in\n                          acknowledgement generation.')
lapbOperT3DisconnectTimer = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 16, 2, 1, 11), PositiveInteger()).setMaxAccess("readonly")
if mibBuilder.loadTexts: lapbOperT3DisconnectTimer.setDescription('The current T3 timer for this interface.\n                          This specifies the time in Milliseconds to\n                          wait before considering the link\n                          disconnected.  A value of zero indicates the\n                          link will be considered disconnected upon\n                          completion of the frame exchange to\n                          disconnect the link.')
lapbOperT4IdleTimer = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 16, 2, 1, 12), PositiveInteger()).setMaxAccess("readwrite")
if mibBuilder.loadTexts: lapbOperT4IdleTimer.setDescription('The current T4 timer for this interface.\n                          This specifies the maximum time in\n                          Milliseconds to allow without frames being\n                          exchanged on the data link.  A value of\n                          2147483647 indicates no idle timer is being\n                          kept.')
lapbOperPortId = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 16, 2, 1, 13), ObjectIdentifier()).setMaxAccess("readonly")
if mibBuilder.loadTexts: lapbOperPortId.setDescription('This object identifies an instance of the\n                          index object in the first group of objects\n                          in the MIB specific to the physical device\n                          or interface used to send and receive\n\n\n                          frames.  If an agent does not support any\n                          such objects, it should return nullSpec\n                          OBJECT IDENTIFIER {0 0}.')
lapbOperProtocolVersionId = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 16, 2, 1, 14), ObjectIdentifier()).setMaxAccess("readonly")
if mibBuilder.loadTexts: lapbOperProtocolVersionId.setDescription('This object identifies the version of the\n                          lapb protocol implemented by this\n                          interface.')
lapbFlowTable = MibTable((1, 3, 6, 1, 2, 1, 10, 16, 3), )
if mibBuilder.loadTexts: lapbFlowTable.setDescription('This table defines the objects recorded by\n                          LAPB to provide information about the\n                          traffic flow through the interface.')
lapbFlowEntry = MibTableRow((1, 3, 6, 1, 2, 1, 10, 16, 3, 1), ).setIndexNames((0, "RFC1381-MIB", "lapbFlowIfIndex"))
if mibBuilder.loadTexts: lapbFlowEntry.setDescription('The information regarding the effects of\n                          flow controls in LAPB.')
lapbFlowIfIndex = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 16, 3, 1, 1), IfIndexType()).setMaxAccess("readonly")
if mibBuilder.loadTexts: lapbFlowIfIndex.setDescription('The ifIndex value for the LAPB Interface.')
lapbFlowStateChanges = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 16, 3, 1, 2), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: lapbFlowStateChanges.setDescription('The number of LAPB State Changes, including\n                          resets.')
lapbFlowChangeReason = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 16, 3, 1, 3), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13,))).clone(namedValues=NamedValues(("notStarted", 1), ("abmEntered", 2), ("abmeEntered", 3), ("abmReset", 4), ("abmeReset", 5), ("dmReceived", 6), ("dmSent", 7), ("discReceived", 8), ("discSent", 9), ("frmrReceived", 10), ("frmrSent", 11), ("n2Timeout", 12), ("other", 13),))).setMaxAccess("readonly")
if mibBuilder.loadTexts: lapbFlowChangeReason.setDescription('The reason for the most recent incrementing\n                          of lapbFlowStateChanges.  A DM or DISC frame\n                          generated to initiate link set-up does not\n                          alter this object.  When the MIB-II object\n                          ifOperStatus does not have a value of\n                          testing, there exists a correlation between\n                          this object and ifOperStatus.  IfOperStatus\n                          will have a value of up when this object\n                          contains:  abmEntered, abmeEntered,\n                          abmReset, or abmeReset.  IfOperStatus will\n                          have a value of down when this object has a\n                          value of notStarted, or dmReceived through\n                          n2Timeout.  There is no correlation when\n                          this object has the value other.')
lapbFlowCurrentMode = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 16, 3, 1, 4), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17,))).clone(namedValues=NamedValues(("disconnected", 1), ("linkSetup", 2), ("frameReject", 3), ("disconnectRequest", 4), ("informationTransfer", 5), ("rejFrameSent", 6), ("waitingAcknowledgement", 7), ("stationBusy", 8), ("remoteStationBusy", 9), ("bothStationsBusy", 10), ("waitingAckStationBusy", 11), ("waitingAckRemoteBusy", 12), ("waitingAckBothBusy", 13), ("rejFrameSentRemoteBusy", 14), ("xidFrameSent", 15), ("error", 16), ("other", 17),))).setMaxAccess("readonly")
if mibBuilder.loadTexts: lapbFlowCurrentMode.setDescription('The current condition of the conversation.')
lapbFlowBusyDefers = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 16, 3, 1, 5), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: lapbFlowBusyDefers.setDescription('The number of times this device was unable\n                          to transmit a frame due to a perceived\n                          remote busy condition.  Busy conditions can\n\n\n                          result from the receipt of an RNR from the\n                          remote device, the lack of valid sequence\n                          number space (window saturation), or other\n                          conditions.')
lapbFlowRejOutPkts = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 16, 3, 1, 6), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: lapbFlowRejOutPkts.setDescription('The number of REJ or SREJ frames sent by\n                          this station.')
lapbFlowRejInPkts = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 16, 3, 1, 7), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: lapbFlowRejInPkts.setDescription('The number of REJ or SREJ frames received\n                          by this station.')
lapbFlowT1Timeouts = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 16, 3, 1, 8), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: lapbFlowT1Timeouts.setDescription('The number of times a re-transmission was\n                          effected by the T1 Timer expiring.')
lapbFlowFrmrSent = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 16, 3, 1, 9), OctetString().subtype(subtypeSpec=ValueSizeConstraint(0,7))).setMaxAccess("readonly")
if mibBuilder.loadTexts: lapbFlowFrmrSent.setDescription("The Information Field of the FRMR most\n                          recently sent.  If no FRMR has been sent\n                          (the normal case) or the information isn't\n                          available, this will be an OCTET STRING of\n                          zero length.")
lapbFlowFrmrReceived = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 16, 3, 1, 10), OctetString().subtype(subtypeSpec=ValueSizeConstraint(0,7))).setMaxAccess("readonly")
if mibBuilder.loadTexts: lapbFlowFrmrReceived.setDescription("The Information Field of the FRMR most\n                          recently received.  If no FRMR has been\n                          received (the normal case) or the\n                          information isn't available, this will be an\n                          OCTET STRING of zero length.")
lapbFlowXidReceived = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 16, 3, 1, 11), OctetString().subtype(subtypeSpec=ValueSizeConstraint(0,8206))).setMaxAccess("readonly")
if mibBuilder.loadTexts: lapbFlowXidReceived.setDescription('The Information Field of the XID frame most\n                          recently received.  If no XID frame has been\n                          received, this will be an OCTET STRING of\n                          zero length.')
lapbXidTable = MibTable((1, 3, 6, 1, 2, 1, 10, 16, 4), )
if mibBuilder.loadTexts: lapbXidTable.setDescription("This table defines values to use for XID\n                          negotiation that are not found in the\n                          lapbAdmnTable.  This table is optional for\n                          implementations that don't support XID and\n                          mandatory for implementations that do\n                          initiate XID negotiation.")
lapbXidEntry = MibTableRow((1, 3, 6, 1, 2, 1, 10, 16, 4, 1), ).setIndexNames((0, "RFC1381-MIB", "lapbXidIndex"))
if mibBuilder.loadTexts: lapbXidEntry.setDescription('XId negotiation parameter values for a\n                          specific LAPB.')
lapbXidIndex = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 16, 4, 1, 1), IfIndexType()).setMaxAccess("readonly")
if mibBuilder.loadTexts: lapbXidIndex.setDescription('The ifIndex value for the LAPB interface.')
lapbXidAdRIdentifier = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 16, 4, 1, 2), OctetString().subtype(subtypeSpec=ValueSizeConstraint(0,255)).clone(hexValue="")).setMaxAccess("readwrite")
if mibBuilder.loadTexts: lapbXidAdRIdentifier.setDescription('The value of the Address Resolution\n                          Identifier.  A zero length string indicates\n                          no Identifier value has been assigned.')
lapbXidAdRAddress = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 16, 4, 1, 3), OctetString().subtype(subtypeSpec=ValueSizeConstraint(0,255)).clone(hexValue="")).setMaxAccess("readwrite")
if mibBuilder.loadTexts: lapbXidAdRAddress.setDescription('The value of the Address Resolution\n                          Address.  A zero length string indicates no\n                          Address value has been assigned.')
lapbXidParameterUniqueIdentifier = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 16, 4, 1, 4), OctetString().subtype(subtypeSpec=ValueSizeConstraint(0,255)).clone(hexValue="")).setMaxAccess("readwrite")
if mibBuilder.loadTexts: lapbXidParameterUniqueIdentifier.setDescription('The value of the parameter unique\n                          Identifier.  A zero length string indicates\n                          no Unique identifier value has been\n                          assigned.')
lapbXidGroupAddress = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 16, 4, 1, 5), OctetString().subtype(subtypeSpec=ValueSizeConstraint(0,255)).clone(hexValue="")).setMaxAccess("readwrite")
if mibBuilder.loadTexts: lapbXidGroupAddress.setDescription('The value of the parameter Group address.\n                          A zero length string indicates no Group\n                          address value has been assigned.')
lapbXidPortNumber = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 16, 4, 1, 6), OctetString().subtype(subtypeSpec=ValueSizeConstraint(0,255)).clone(hexValue="")).setMaxAccess("readwrite")
if mibBuilder.loadTexts: lapbXidPortNumber.setDescription('The port number assigned for this link.  A\n                          zero length string indicates no local port\n                          number identifier has been assigned.')
lapbXidUserDataSubfield = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 16, 4, 1, 7), OctetString().subtype(subtypeSpec=ValueSizeConstraint(0,8206)).clone(hexValue="")).setMaxAccess("readwrite")
if mibBuilder.loadTexts: lapbXidUserDataSubfield.setDescription('A user data subfield, if any, to be\n                          transmitted in an XID frame.  A zero length\n                          frame indicates no user data subfield has\n                          been assigned.  The octet string should\n                          include both the User data identifier and\n                          User data field as shown in Figures 1 and\n                          4.')
lapbProtocolVersion = MibIdentifier((1, 3, 6, 1, 2, 1, 10, 16, 5))
lapbProtocolIso7776v1986 = MibIdentifier((1, 3, 6, 1, 2, 1, 10, 16, 5, 1))
lapbProtocolCcittV1980 = MibIdentifier((1, 3, 6, 1, 2, 1, 10, 16, 5, 2))
lapbProtocolCcittV1984 = MibIdentifier((1, 3, 6, 1, 2, 1, 10, 16, 5, 3))
mibBuilder.exportSymbols("RFC1381-MIB", lapbXidPortNumber=lapbXidPortNumber, lapbOperTransmitN1FrameSize=lapbOperTransmitN1FrameSize, lapbProtocolCcittV1984=lapbProtocolCcittV1984, lapbOperT4IdleTimer=lapbOperT4IdleTimer, lapbAdmnReceiveKWindowSize=lapbAdmnReceiveKWindowSize, lapbFlowTable=lapbFlowTable, lapbAdmnN2RxmitCount=lapbAdmnN2RxmitCount, lapbAdmnT3DisconnectTimer=lapbAdmnT3DisconnectTimer, lapbAdmnT4IdleTimer=lapbAdmnT4IdleTimer, lapbFlowFrmrSent=lapbFlowFrmrSent, lapbAdmnControlField=lapbAdmnControlField, lapbOperPortId=lapbOperPortId, lapbOperIndex=lapbOperIndex, lapbAdmnTransmitKWindowSize=lapbAdmnTransmitKWindowSize, lapbOperTransmitKWindowSize=lapbOperTransmitKWindowSize, lapbFlowStateChanges=lapbFlowStateChanges, lapbAdmnEntry=lapbAdmnEntry, lapbXidIndex=lapbXidIndex, lapbAdmnReceiveN1FrameSize=lapbAdmnReceiveN1FrameSize, lapbFlowT1Timeouts=lapbFlowT1Timeouts, lapbOperReceiveN1FrameSize=lapbOperReceiveN1FrameSize, lapbFlowEntry=lapbFlowEntry, lapbXidTable=lapbXidTable, lapbProtocolCcittV1980=lapbProtocolCcittV1980, lapbAdmnIndex=lapbAdmnIndex, lapbAdmnTransmitN1FrameSize=lapbAdmnTransmitN1FrameSize, lapbFlowRejOutPkts=lapbFlowRejOutPkts, lapbFlowFrmrReceived=lapbFlowFrmrReceived, lapbXidUserDataSubfield=lapbXidUserDataSubfield, lapbOperT2AckDelayTimer=lapbOperT2AckDelayTimer, lapbXidGroupAddress=lapbXidGroupAddress, lapbFlowChangeReason=lapbFlowChangeReason, lapbFlowRejInPkts=lapbFlowRejInPkts, lapbAdmnActionRecvDM=lapbAdmnActionRecvDM, lapbOperProtocolVersionId=lapbOperProtocolVersionId, lapbFlowBusyDefers=lapbFlowBusyDefers, lapbFlowCurrentMode=lapbFlowCurrentMode, lapbFlowXidReceived=lapbFlowXidReceived, lapb=lapb, lapbOperN2RxmitCount=lapbOperN2RxmitCount, lapbAdmnT2AckDelayTimer=lapbAdmnT2AckDelayTimer, lapbOperT3DisconnectTimer=lapbOperT3DisconnectTimer, lapbXidEntry=lapbXidEntry, lapbOperReceiveKWindowSize=lapbOperReceiveKWindowSize, IfIndexType=IfIndexType, lapbAdmnActionInitiate=lapbAdmnActionInitiate, lapbProtocolVersion=lapbProtocolVersion, lapbAdmnStationType=lapbAdmnStationType, lapbAdmnT1AckTimer=lapbAdmnT1AckTimer, lapbXidAdRIdentifier=lapbXidAdRIdentifier, lapbOperControlField=lapbOperControlField, lapbOperT1AckTimer=lapbOperT1AckTimer, lapbFlowIfIndex=lapbFlowIfIndex, lapbXidParameterUniqueIdentifier=lapbXidParameterUniqueIdentifier, lapbOperEntry=lapbOperEntry, lapbXidAdRAddress=lapbXidAdRAddress, lapbProtocolIso7776v1986=lapbProtocolIso7776v1986, lapbAdmnTable=lapbAdmnTable, lapbOperTable=lapbOperTable, lapbOperStationType=lapbOperStationType)



#
# PySNMP MIB module DOCS-IETF-SUBMGT-MIB (http://pysnmp.sf.net)
# ASN.1 source http://mibs.snmplabs.com:80/asn1/DOCS-IETF-SUBMGT-MIB
# Produced by pysmi-0.0.7 at Sun Feb 14 00:10:10 2016
# On host bldfarm platform Linux version 4.1.13-100.fc21.x86_64 by user goose
# Using Python version 3.5.0 (default, Jan  5 2016, 17:11:52) 
#
( OctetString, ObjectIdentifier, Integer, ) = mibBuilder.importSymbols("ASN1", "OctetString", "ObjectIdentifier", "Integer")
( NamedValues, ) = mibBuilder.importSymbols("ASN1-ENUMERATION", "NamedValues")
( ConstraintsIntersection, ConstraintsUnion, ValueSizeConstraint, ValueRangeConstraint, SingleValueConstraint, ) = mibBuilder.importSymbols("ASN1-REFINEMENT", "ConstraintsIntersection", "ConstraintsUnion", "ValueSizeConstraint", "ValueRangeConstraint", "SingleValueConstraint")
( diffServDataPathStorage, diffServAlgDropStorage, diffServMIBMultiFieldClfrGroup, diffServClfrElementStatus, diffServMIBCounterGroup, diffServActionStorage, diffServClfrElementStorage, diffServCountActStorage, diffServAlgDropStatus, diffServMIBClfrGroup, diffServMIBAlgDropGroup, diffServDataPathStatus, diffServMultiFieldClfrDstAddr, diffServClfrStorage, diffServMIBActionGroup, diffServClfrStatus, diffServMIBClfrElementGroup, diffServMIBDataPathGroup, diffServAlgDropType, diffServMultiFieldClfrAddrType, diffServMultiFieldClfrSrcAddr, diffServMultiFieldClfrStorage, ) = mibBuilder.importSymbols("DIFFSERV-MIB", "diffServDataPathStorage", "diffServAlgDropStorage", "diffServMIBMultiFieldClfrGroup", "diffServClfrElementStatus", "diffServMIBCounterGroup", "diffServActionStorage", "diffServClfrElementStorage", "diffServCountActStorage", "diffServAlgDropStatus", "diffServMIBClfrGroup", "diffServMIBAlgDropGroup", "diffServDataPathStatus", "diffServMultiFieldClfrDstAddr", "diffServClfrStorage", "diffServMIBActionGroup", "diffServClfrStatus", "diffServMIBClfrElementGroup", "diffServMIBDataPathGroup", "diffServAlgDropType", "diffServMultiFieldClfrAddrType", "diffServMultiFieldClfrSrcAddr", "diffServMultiFieldClfrStorage")
( docsIfCmtsCmStatusEntry, docsIfCmtsCmStatusIndex, ) = mibBuilder.importSymbols("DOCS-IF-MIB", "docsIfCmtsCmStatusEntry", "docsIfCmtsCmStatusIndex")
( InetAddressType, InetAddress, ) = mibBuilder.importSymbols("INET-ADDRESS-MIB", "InetAddressType", "InetAddress")
( NotificationGroup, ObjectGroup, ModuleCompliance, ) = mibBuilder.importSymbols("SNMPv2-CONF", "NotificationGroup", "ObjectGroup", "ModuleCompliance")
( Counter64, TimeTicks, iso, Integer32, ObjectIdentity, MibIdentifier, Gauge32, Unsigned32, IpAddress, NotificationType, Counter32, mib_2, MibScalar, MibTable, MibTableRow, MibTableColumn, Bits, ModuleIdentity, ) = mibBuilder.importSymbols("SNMPv2-SMI", "Counter64", "TimeTicks", "iso", "Integer32", "ObjectIdentity", "MibIdentifier", "Gauge32", "Unsigned32", "IpAddress", "NotificationType", "Counter32", "mib-2", "MibScalar", "MibTable", "MibTableRow", "MibTableColumn", "Bits", "ModuleIdentity")
( StorageType, RowStatus, DisplayString, TextualConvention, TimeStamp, TruthValue, ) = mibBuilder.importSymbols("SNMPv2-TC", "StorageType", "RowStatus", "DisplayString", "TextualConvention", "TimeStamp", "TruthValue")
docsSubMgt = ModuleIdentity((1, 3, 6, 1, 2, 1, 125)).setRevisions(("2005-03-29 00:00",))
if mibBuilder.loadTexts: docsSubMgt.setLastUpdated('200503290000Z')
if mibBuilder.loadTexts: docsSubMgt.setOrganization('IETF IP over Cable Data Network (IPCDN) Working\n                     Group')
if mibBuilder.loadTexts: docsSubMgt.setContactInfo('        Wilson Sawyer\n         Postal: 50 Kelly Brook Lane\n                 East Hampstead, NH 03826\n                 U.S.A.\n\n         Phone:  +1 603 382 7080\n         E-mail: wsawyer@ieee.org\n\n         IETF IPCDN Working Group\n         General Discussion: ipcdn@ietf.org\n         Subscribe: http://www.ietf.org/mailman/listinfo/ipcdn\n         Archive: ftp://ftp.ietf.org/ietf-mail-archive/ipcdn\n         Co-chairs: Richard Woundy, Richard_Woundy@cable.comcast.com\n                    Jean-Francois Mule, jf.mule@cablelabs.com')
if mibBuilder.loadTexts: docsSubMgt.setDescription("This is the CMTS centric subscriber management MIB for\n    DOCSIS-compliant CMTS.  It provides the objects to allow a Cable\n    Modem Termination operator to control the IP addresses and\n    protocols associated with subscribers' cable modems.\n\n\n\n\n\n\n    Copyright (C) The Internet Society (2005).  This version of this\n    MIB module is part of RFC 4036; see the RFC itself for full legal\n    notices.")
docsSubMgtObjects = MibIdentifier((1, 3, 6, 1, 2, 1, 125, 1))
docsSubMgtCpeControlTable = MibTable((1, 3, 6, 1, 2, 1, 125, 1, 1), )
if mibBuilder.loadTexts: docsSubMgtCpeControlTable.setDescription('This table AUGMENTs the docsIfCmtsCmStatusTable, adding\n    four WRITEable objects, as well as a read-only object, all of\n    which reflect the state of subscriber management on a particular\n    CM.')
docsSubMgtCpeControlEntry = MibTableRow((1, 3, 6, 1, 2, 1, 125, 1, 1, 1), )
docsIfCmtsCmStatusEntry.registerAugmentions(("DOCS-IETF-SUBMGT-MIB", "docsSubMgtCpeControlEntry"))
docsSubMgtCpeControlEntry.setIndexNames(*docsIfCmtsCmStatusEntry.getIndexNames())
if mibBuilder.loadTexts: docsSubMgtCpeControlEntry.setDescription('A row in the docsSubMgtCpeControlTable.  All values are set\n    at successful modem registration, either from the system default,\n    or from objects included in the DOCSIS registration request sent\n    upstream to the CMTS from the CM.  The contents of this entry are\n    meaningless unless the corresponding docsIfCmtsCmStatusValue (see\n    reference) is registrationComplete(6).  The persistence of this\n    row is determined solely by the lifespan of the corresponding\n    docsIfCmtsCmStatusEntry (normally StorageType=volatile).')
docsSubMgtCpeControlMaxCpeIp = MibTableColumn((1, 3, 6, 1, 2, 1, 125, 1, 1, 1, 1), Integer32().subtype(subtypeSpec=ValueRangeConstraint(0,2147483647))).setMaxAccess("readwrite")
if mibBuilder.loadTexts: docsSubMgtCpeControlMaxCpeIp.setDescription('The number of simultaneous IP addresses permitted behind\n    the CM.  If this is set to zero, all CPE traffic from the CM is\n    dropped.  If the provisioning object corresponding to\n    docsSubMgtCpeIpTable includes more CPE IP address entries for\n    this modem than the value of this object, then this object is\n    set to the count of the number of rows in docsSubMgtCpeIpTable\n    that have the same docsIfCmtsCmStatusIndex value.  (For example,\n    if the CM has 5 IP addresses specified for it, this value is 5.)\n    This limit applies to learned and DOCSIS-provisioned entries\n    but not to entries added through some administrative\n    process at the CMTS.  If not set through DOCSIS provisioning,\n    this object defaults to docsSubMgtCpeMaxIpDefault.  Note that\n    this object is only meaningful if docsSubMgtCpeControlActive\n    is true.')
docsSubMgtCpeControlActive = MibTableColumn((1, 3, 6, 1, 2, 1, 125, 1, 1, 1, 2), TruthValue()).setMaxAccess("readwrite")
if mibBuilder.loadTexts: docsSubMgtCpeControlActive.setDescription('Controls the application of subscriber management to\n    this cable modem.  If this is set to true, CMTS-based CPE\n    control is active, and all the actions required by the various\n    filter tables and controls apply at the CMTS.  If this is set\n    to false, no subscriber management filtering is done at the\n    CMTS (but other filters may apply).  If not set through DOCSIS\n    provisioning, this object defaults to\n    docsSubMgtCpeActiveDefault.')
docsSubMgtCpeControlLearnable = MibTableColumn((1, 3, 6, 1, 2, 1, 125, 1, 1, 1, 3), TruthValue()).setMaxAccess("readwrite")
if mibBuilder.loadTexts: docsSubMgtCpeControlLearnable.setDescription('Controls whether the CMTS may learn (and pass traffic\n    for) CPE IP addresses associated with a cable modem.  If this is\n    set to true, the CMTS may learn up to docsSubMgtMaxCpeIp\n\n\n\n    addresses (less any DOCSIS-provisioned entries) related to this\n    CM.  Those IP addresses are added (by internal process) to the\n    docsSubMgtCpeIpTable.  The nature of the learning mechanism is\n    not specified here.\n\n    If not set through DOCSIS provisioning, this object defaults to\n    docsSubMgtCpeLearnableDefault.  Note that this object is only\n    meaningful if docsSubMgtCpeControlActive is true.')
docsSubMgtCpeControlReset = MibTableColumn((1, 3, 6, 1, 2, 1, 125, 1, 1, 1, 4), TruthValue()).setMaxAccess("readwrite")
if mibBuilder.loadTexts: docsSubMgtCpeControlReset.setDescription("This object always returns false on read.  If this object is\n    set to true, the rows with 'learned' addresses in\n    docsSubMgtCpeIpTable for this CM are deleted from that table.")
docsSubMgtCpeControlLastReset = MibTableColumn((1, 3, 6, 1, 2, 1, 125, 1, 1, 1, 5), TimeStamp()).setMaxAccess("readonly")
if mibBuilder.loadTexts: docsSubMgtCpeControlLastReset.setDescription('The value of sysUpTime when docsSubMgtCpeControlReset was\n    last set true.  Zero if never reset.')
docsSubMgtCpeMaxIpDefault = MibScalar((1, 3, 6, 1, 2, 1, 125, 1, 2), Integer32().subtype(subtypeSpec=ValueRangeConstraint(0,2147483647)).clone(16)).setMaxAccess("readwrite")
if mibBuilder.loadTexts: docsSubMgtCpeMaxIpDefault.setDescription('The default value for docsSubMgtCpeControlMaxCpeIp if not\n    signaled in the DOCSIS Registration request.  This value should\n    be treated as nonvolatile; if set, its value should persist\n    across device resets.')
docsSubMgtCpeActiveDefault = MibScalar((1, 3, 6, 1, 2, 1, 125, 1, 3), TruthValue().clone('false')).setMaxAccess("readwrite")
if mibBuilder.loadTexts: docsSubMgtCpeActiveDefault.setDescription('The default value for docsSubMgtCpeControlActive if not\n\n\n\n    signaled in the DOCSIS Registration request.  This value should\n    be treated as nonvolatile; if set, its value should persist\n    across device resets.')
docsSubMgtCpeLearnableDefault = MibScalar((1, 3, 6, 1, 2, 1, 125, 1, 4), TruthValue().clone('true')).setMaxAccess("readwrite")
if mibBuilder.loadTexts: docsSubMgtCpeLearnableDefault.setDescription('The default value for docsSubMgtCpeControlLearnable if not\n    signaled in the DOCSIS Registration request.  This value should\n    be treated as nonvolatile; if set, its value should persist\n    across device resets.')
docsSubMgtCpeIpTable = MibTable((1, 3, 6, 1, 2, 1, 125, 1, 5), )
if mibBuilder.loadTexts: docsSubMgtCpeIpTable.setDescription('A table of CPE IP addresses known on a per-CM basis.')
docsSubMgtCpeIpEntry = MibTableRow((1, 3, 6, 1, 2, 1, 125, 1, 5, 1), ).setIndexNames((0, "DOCS-IF-MIB", "docsIfCmtsCmStatusIndex"), (0, "DOCS-IETF-SUBMGT-MIB", "docsSubMgtCpeIpIndex"))
if mibBuilder.loadTexts: docsSubMgtCpeIpEntry.setDescription("An entry in the docsSubMgtCpeIpTable.  The first index is\n    the specific modem we're referring to, and the second index is\n    the specific CPE IP entry.")
docsSubMgtCpeIpIndex = MibTableColumn((1, 3, 6, 1, 2, 1, 125, 1, 5, 1, 1), Integer32().subtype(subtypeSpec=ValueRangeConstraint(1,2147483647)))
if mibBuilder.loadTexts: docsSubMgtCpeIpIndex.setDescription('The index of this CPE IP address relative to the indexed CM.\n    An entry is created either through the included CPE IP addresses\n    in the provisioning object, or via learning.\n\n    If docsSubMgtCpeControlActive is true and a CMTS receives\n    an IP packet from a CM that contains a source IP address that\n    does not match one of the docsSubMgtCpeIpAddr entries for this\n    CM, one of two things occurs.  If the number of entries is less\n    than docsSubMgtCpeControlMaxCpeIp, the source address is added to\n    the table and the packet is forwarded.  If the number of entries\n    equals the docsSubMgtCpeControlMaxCpeIp, then the packet is\n    dropped.')
docsSubMgtCpeIpAddressType = MibTableColumn((1, 3, 6, 1, 2, 1, 125, 1, 5, 1, 2), InetAddressType()).setMaxAccess("readonly")
if mibBuilder.loadTexts: docsSubMgtCpeIpAddressType.setDescription('The type of internet address of docsSubMgtCpeIpAddr.')
docsSubMgtCpeIpAddr = MibTableColumn((1, 3, 6, 1, 2, 1, 125, 1, 5, 1, 3), InetAddress()).setMaxAccess("readonly")
if mibBuilder.loadTexts: docsSubMgtCpeIpAddr.setDescription('The IP address either set from provisioning or learned via\n    address gleaning or other forwarding means.  See\n    docsSubMgtCpeIpIndex for the mechanism.\n\n    The type of this address is determined by the value of\n    docsSubMgtCpeIpAddressType.')
docsSubMgtCpeIpLearned = MibTableColumn((1, 3, 6, 1, 2, 1, 125, 1, 5, 1, 4), TruthValue()).setMaxAccess("readonly")
if mibBuilder.loadTexts: docsSubMgtCpeIpLearned.setDescription('If true, this entry was learned from IP packets sent\n    upstream rather than from the provisioning objects.')
docsSubMgtCmFilterTable = MibTable((1, 3, 6, 1, 2, 1, 125, 1, 6), )
if mibBuilder.loadTexts: docsSubMgtCmFilterTable.setDescription('Binds filter groups to modems, identifying for each modem\n    the upstream and downstream filter groups that apply to packets\n    for that modem.  Normally, this table reflects the filter group\n    values signaled by DOCSIS Registration, although values may be\n    overridden by management action.\n\n    For each of the columns in this table, zero is a distinguished\n    value, indicating that the default filtering action is to be\n    taken rather than that associated with a filter group number.\n    Zero is used if the filter group is not signaled by DOCSIS\n    registration.')
docsSubMgtCmFilterEntry = MibTableRow((1, 3, 6, 1, 2, 1, 125, 1, 6, 1), )
docsIfCmtsCmStatusEntry.registerAugmentions(("DOCS-IETF-SUBMGT-MIB", "docsSubMgtCmFilterEntry"))
docsSubMgtCmFilterEntry.setIndexNames(*docsIfCmtsCmStatusEntry.getIndexNames())
if mibBuilder.loadTexts: docsSubMgtCmFilterEntry.setDescription('Binds a filter group to each direction of traffic for a\n    modem.  The filters in this entry apply if\n    docsSubMgtCpeControlActive is true.\n\n    The contents of this entry are meaningless unless the\n    corresponding docsIfCmtsCmStatusValue (see reference) is\n    registrationComplete(6).  The persistence of this row is\n    determined solely by the lifespan of the corresponding\n    docsIfCmtsCmStatusEntry (normally StorageType=volatile).')
docsSubMgtCmFilterSubDownstream = MibTableColumn((1, 3, 6, 1, 2, 1, 125, 1, 6, 1, 1), Integer32().subtype(subtypeSpec=ValueRangeConstraint(0,65535))).setMaxAccess("readwrite")
if mibBuilder.loadTexts: docsSubMgtCmFilterSubDownstream.setDescription('The filter group applied to traffic destined for subscribers\n    attached to the referenced CM.  Upon row creation, this is set\n    either to zero (use default classification, the\n    diffServClfrElementSpecific=zeroDotZero row of\n    diffServClfrElementTable) or to the value in the provisioning\n    object sent upstream from the CM to the CMTS during registration.\n    The value of this object is the same as that of the filter group\n    index appearing as docsSubMgtFilterGroupIndex.')
docsSubMgtCmFilterSubUpstream = MibTableColumn((1, 3, 6, 1, 2, 1, 125, 1, 6, 1, 2), Integer32().subtype(subtypeSpec=ValueRangeConstraint(0,65535))).setMaxAccess("readwrite")
if mibBuilder.loadTexts: docsSubMgtCmFilterSubUpstream.setDescription('The filter group applied to traffic originating from\n    subscribers attached to the referenced CM.  Upon row creation\n    this is set to either zero (use default classification, the\n    diffServClfrElementSpecific=zeroDotZero row of\n    diffServClfrElementTable), or to the value in the provisioning\n    object sent upstream from the CM to the CMTS.  The value of this\n    object is the same as that of the filter group index appearing as\n    docsSubMgtFilterGroupIndex.')
docsSubMgtCmFilterCmDownstream = MibTableColumn((1, 3, 6, 1, 2, 1, 125, 1, 6, 1, 3), Integer32().subtype(subtypeSpec=ValueRangeConstraint(0,65535))).setMaxAccess("readwrite")
if mibBuilder.loadTexts: docsSubMgtCmFilterCmDownstream.setDescription('The filter group applied to traffic destined for the\n    referenced CM itself.  Upon row creation this is set either to\n    zero (use default classification, the\n    diffServClfrElementSpecific=zeroDotZero row of\n    diffServClfrElementTable), or to the value in the provisioning\n    object sent upstream from the CM to the CMTS during registration.\n    The value of this object is the same as that of the filter group\n    index appearing as docsSubMgtFilterGroupIndex.')
docsSubMgtCmFilterCmUpstream = MibTableColumn((1, 3, 6, 1, 2, 1, 125, 1, 6, 1, 4), Integer32().subtype(subtypeSpec=ValueRangeConstraint(0,65535))).setMaxAccess("readwrite")
if mibBuilder.loadTexts: docsSubMgtCmFilterCmUpstream.setDescription('The filter group applied to traffic originating from the\n    referenced CM itself.  This is set upon row creation to either\n\n\n\n    zero (use default classification, the\n    diffServClfrElementSpecific=zeroDotZero row of\n    diffServClfrElementTable), or to the value in the provisioning\n    object sent upstream from the CM to the CMTS during registration.\n    The value of this object is the same as the filter group index\n    appearing as docsSubMgtFilterGroupIndex.')
docsSubMgtFilterGroupTable = MibTable((1, 3, 6, 1, 2, 1, 125, 1, 7), )
if mibBuilder.loadTexts: docsSubMgtFilterGroupTable.setDescription('Provides a collection of referenceable entries to which\n    diffServClfrElementSpecific refers.  This table provides filter\n    group indices that can be compared with those signaled during\n    DOCSIS registration.  A packet matches an entry from this table\n    if the packet originated from or is destined to a cable modem\n    that registered this index as one of its four filter groups\n    (see docsSubMgtCmFilterTable), and if the packet direction and\n    MAC address select the use of this index among the four.')
docsSubMgtFilterGroupEntry = MibTableRow((1, 3, 6, 1, 2, 1, 125, 1, 7, 1), ).setIndexNames((0, "DOCS-IETF-SUBMGT-MIB", "docsSubMgtFilterGroupIndex"))
if mibBuilder.loadTexts: docsSubMgtFilterGroupEntry.setDescription("An entry only exists if needed by the\n    diffServClfrElementEntry.  A packet matches this entry if the\n    packet's cable modem registered this index as one of its four\n    filter groups (see docsSubMgtCmFilterTable) and if the packet\n    direction and MAC address select the use of this index among\n    the four.")
docsSubMgtFilterGroupIndex = MibTableColumn((1, 3, 6, 1, 2, 1, 125, 1, 7, 1, 1), Integer32().subtype(subtypeSpec=ValueRangeConstraint(1,65535))).setMaxAccess("readonly")
if mibBuilder.loadTexts: docsSubMgtFilterGroupIndex.setDescription("The filter group index, from the set signaled at DOCSIS\n\n\n\n    Registration.  Provides a referenceable entry to which\n    diffServClfrElementSpecific points.  A packet matches this\n    classifier entry if the packet's cable modem registered this\n    index value as one of its four filter groups, and if the packet\n    direction and MAC address select the use of this index among\n    the four.  Because this is the only field in this table, it is\n    read-only, contrary to the usual SMI custom of making indices\n    not-accessible.\n\n    Note that although zero may be signaled (or defaulted) at DOCSIS\n    Registration to indicate a default filtering group, no such entry\n    appears in this table, as diffServClfrElementSpecific will\n    use a zeroDotZero pointer for that classification.")
docsSubMgtConformance = MibIdentifier((1, 3, 6, 1, 2, 1, 125, 2))
docsSubMgtCompliances = MibIdentifier((1, 3, 6, 1, 2, 1, 125, 2, 1))
docsSubMgtGroups = MibIdentifier((1, 3, 6, 1, 2, 1, 125, 2, 2))
docsSubMgtBasicCompliance = ModuleCompliance((1, 3, 6, 1, 2, 1, 125, 2, 1, 1)).setObjects(*(("DIFFSERV-MIB", "diffServMIBDataPathGroup"), ("DIFFSERV-MIB", "diffServMIBClfrGroup"), ("DIFFSERV-MIB", "diffServMIBClfrElementGroup"), ("DIFFSERV-MIB", "diffServMIBMultiFieldClfrGroup"), ("DIFFSERV-MIB", "diffServMIBActionGroup"), ("DIFFSERV-MIB", "diffServMIBAlgDropGroup"), ("DIFFSERV-MIB", "diffServMIBCounterGroup"), ("DOCS-IETF-SUBMGT-MIB", "docsSubMgtGroup"),))
if mibBuilder.loadTexts: docsSubMgtBasicCompliance.setDescription('The compliance statement for CMTS devices that implement\n    CMTS centric subscriber management.\n\n    This compliance statement applies to implementations that\n    support DOCSIS 1.0/1.1/2.0, which are not IPv6 capable.')
docsSubMgtGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 125, 2, 2, 1)).setObjects(*(("DOCS-IETF-SUBMGT-MIB", "docsSubMgtCpeControlMaxCpeIp"), ("DOCS-IETF-SUBMGT-MIB", "docsSubMgtCpeControlActive"), ("DOCS-IETF-SUBMGT-MIB", "docsSubMgtCpeControlLearnable"), ("DOCS-IETF-SUBMGT-MIB", "docsSubMgtCpeControlReset"), ("DOCS-IETF-SUBMGT-MIB", "docsSubMgtCpeControlLastReset"), ("DOCS-IETF-SUBMGT-MIB", "docsSubMgtCpeMaxIpDefault"), ("DOCS-IETF-SUBMGT-MIB", "docsSubMgtCpeActiveDefault"), ("DOCS-IETF-SUBMGT-MIB", "docsSubMgtCpeLearnableDefault"), ("DOCS-IETF-SUBMGT-MIB", "docsSubMgtCpeIpAddressType"), ("DOCS-IETF-SUBMGT-MIB", "docsSubMgtCpeIpAddr"), ("DOCS-IETF-SUBMGT-MIB", "docsSubMgtCpeIpLearned"), ("DOCS-IETF-SUBMGT-MIB", "docsSubMgtCmFilterSubDownstream"), ("DOCS-IETF-SUBMGT-MIB", "docsSubMgtCmFilterSubUpstream"), ("DOCS-IETF-SUBMGT-MIB", "docsSubMgtCmFilterCmDownstream"), ("DOCS-IETF-SUBMGT-MIB", "docsSubMgtCmFilterCmUpstream"), ("DOCS-IETF-SUBMGT-MIB", "docsSubMgtFilterGroupIndex"),))
if mibBuilder.loadTexts: docsSubMgtGroup.setDescription('The objects used to manage host-based cable modems\n            via a set of CMTS enforced controls.')
mibBuilder.exportSymbols("DOCS-IETF-SUBMGT-MIB", docsSubMgtCmFilterSubDownstream=docsSubMgtCmFilterSubDownstream, docsSubMgtCpeLearnableDefault=docsSubMgtCpeLearnableDefault, docsSubMgtCpeIpLearned=docsSubMgtCpeIpLearned, docsSubMgtCmFilterCmUpstream=docsSubMgtCmFilterCmUpstream, docsSubMgtCpeIpEntry=docsSubMgtCpeIpEntry, docsSubMgtCmFilterEntry=docsSubMgtCmFilterEntry, docsSubMgtCpeIpTable=docsSubMgtCpeIpTable, docsSubMgt=docsSubMgt, docsSubMgtCmFilterTable=docsSubMgtCmFilterTable, docsSubMgtCompliances=docsSubMgtCompliances, docsSubMgtCpeControlActive=docsSubMgtCpeControlActive, docsSubMgtGroups=docsSubMgtGroups, docsSubMgtCpeControlTable=docsSubMgtCpeControlTable, docsSubMgtFilterGroupTable=docsSubMgtFilterGroupTable, docsSubMgtFilterGroupEntry=docsSubMgtFilterGroupEntry, docsSubMgtConformance=docsSubMgtConformance, docsSubMgtCpeControlLastReset=docsSubMgtCpeControlLastReset, docsSubMgtCpeMaxIpDefault=docsSubMgtCpeMaxIpDefault, docsSubMgtCpeControlEntry=docsSubMgtCpeControlEntry, docsSubMgtCmFilterSubUpstream=docsSubMgtCmFilterSubUpstream, docsSubMgtFilterGroupIndex=docsSubMgtFilterGroupIndex, docsSubMgtGroup=docsSubMgtGroup, docsSubMgtCpeControlLearnable=docsSubMgtCpeControlLearnable, docsSubMgtCpeIpAddr=docsSubMgtCpeIpAddr, docsSubMgtCpeActiveDefault=docsSubMgtCpeActiveDefault, docsSubMgtCmFilterCmDownstream=docsSubMgtCmFilterCmDownstream, docsSubMgtCpeControlMaxCpeIp=docsSubMgtCpeControlMaxCpeIp, docsSubMgtObjects=docsSubMgtObjects, docsSubMgtBasicCompliance=docsSubMgtBasicCompliance, docsSubMgtCpeControlReset=docsSubMgtCpeControlReset, docsSubMgtCpeIpIndex=docsSubMgtCpeIpIndex, PYSNMP_MODULE_ID=docsSubMgt, docsSubMgtCpeIpAddressType=docsSubMgtCpeIpAddressType)
